@@ -79,11 +79,27 @@ from .models.guardrails import (
     GuardrailAssignmentRequest,
     GuardrailAssignmentResponse,
 )
+from .models.analytics import (
+    ResponseMetadata,
+    PaginationMetadata,
+    ColumnDefinition,
+    Metric,
+    SummariesData,
+    TabularData,
+    UserListItem,
+    UsersListData,
+    SummariesResponse,
+    TabularResponse,
+    UsersListResponse,
+    AnalyticsQueryParams,
+    PaginatedAnalyticsQueryParams,
+)
 from .services.vendor_assistant import VendorAssistantService
 from .services.vendor_workflow import VendorWorkflowService
 from .services.vendor_knowledgebase import VendorKnowledgeBaseService
 from .services.vendor_guardrail import VendorGuardrailService
 from .services.codemie_guardrails import CodemieGuardrailService
+from .services.analytics import AnalyticsService
 
 __version__ = "0.2.12"
 __all__ = [
@@ -144,4 +160,18 @@ __all__ = [
     "GuardrailAssignmentRequest",
     "GuardrailAssignmentResponse",
     "CodemieGuardrailService",
+    "ResponseMetadata",
+    "PaginationMetadata",
+    "ColumnDefinition",
+    "Metric",
+    "SummariesData",
+    "TabularData",
+    "UserListItem",
+    "UsersListData",
+    "SummariesResponse",
+    "TabularResponse",
+    "UsersListResponse",
+    "AnalyticsQueryParams",
+    "PaginatedAnalyticsQueryParams",
+    "AnalyticsService",
 ]
