@@ -4,6 +4,7 @@ from typing import Optional
 
 from ..auth.credentials import KeycloakCredentials
 from ..services.admin import AdminService
+from ..services.analytics import AnalyticsService
 from ..services.assistant import AssistantService
 from ..services.conversation import ConversationService
 from ..services.datasource import DatasourceService
@@ -18,6 +19,7 @@ from ..services.vendor_assistant import VendorAssistantService
 from ..services.vendor_workflow import VendorWorkflowService
 from ..services.vendor_knowledgebase import VendorKnowledgeBaseService
 from ..services.vendor_guardrail import VendorGuardrailService
+from ..services.codemie_guardrails import CodemieGuardrailService
 
 
 class CodeMieClient:
@@ -71,6 +73,9 @@ class CodeMieClient:
 
         # Initialize services with verify_ssl parameter and token
         self.admin = AdminService(self._api_domain, self._token, verify_ssl=verify_ssl)
+        self.analytics = AnalyticsService(
+            self._api_domain, self._token, verify_ssl=verify_ssl
+        )
         self.assistants = AssistantService(
             self._api_domain, self._token, verify_ssl=verify_ssl
         )
@@ -107,6 +112,9 @@ class CodeMieClient:
         self.vendor_guardrails = VendorGuardrailService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.codemie_guardrails = CodemieGuardrailService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
 
     @property
     def token(self) -> str:
@@ -133,6 +141,9 @@ class CodeMieClient:
         self.admin = AdminService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.analytics = AnalyticsService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         self.assistants = AssistantService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
@@ -175,4 +186,7 @@ class CodeMieClient:
         self.vendor_guardrails = VendorGuardrailService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.codemie_guardrails = CodemieGuardrailService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         return self._token
